package com.ym.mec.im.fallback;

import com.ym.mec.common.entity.*;
import com.ym.mec.im.ImFeignService;
import com.ym.mec.im.entity.GroupModel;
import org.springframework.stereotype.Component;

import java.util.List;

@Component
public class ImFeignServiceFallback implements ImFeignService {
    @Override
    public ImResult register(ImUserModel userModel) {
        System.out.println("*******************");
        return null;
    }

    @Override
    public void update(ImUserModel userModel) {

    }

    @Override
    public Object groupCreate(GroupModel groupModel) {
        return null;
    }

    @Override
    public Object groupUpdate(GroupModel groupModel) {
        return null;
    }

    @Override
    public void groupBatchCreate(List<GroupModel> groupModels) {

    }

    @Override
    public Object groupJoin(GroupModel groupModel) {
        return null;
    }

    @Override
    public Object groupBatchJoin(List<GroupModel> groupModels) {
        return null;
    }

    @Override
    public Object groupQuit(GroupModel groupModel) {
        return null;
    }

    @Override
    public Object groupDismiss(GroupModel groupModel) {
        return null;
    }

    @Override
    public Object groupBatchDismiss(List<ImGroupModel> groupModels) {
        return null;
    }

    @Override
    public Object groupBatchQuit(List<GroupModel> groupModels) {
        return null;
    }

    @Override
    public Object privateSend(ImMessageDto imMessageDto) {
        return null;
    }

    @Override
    public Object groupSend(ImMessageDto imMessageDto) {
        return null;
    }

    @Override
    public Object historyGet(String date) {
        return null;
    }

    @Override
    public Object createLiveRoom(String roomId, String roomName) {
        return null;
    }

    @Override
    public Object destroyLiveRoom(String roomId) {
        return null;
    }

    @Override
    public void startRecord(String roomId, String videoResolution) {

    }

    @Override
    public Object publishRoomMsg(ImRoomMessage message) {
        return null;
    }

    @Override
    public void stopRecord(String roomId) {

    }

    @Override
    public boolean userExistInRoom(String chatroomId, String userId) {
        return false;
    }

    @Override
    public boolean checkOnline(String userId) {
        return false;
    }

    @Override
    public boolean addUserUnableSpeak(String roomUid, String userId) {
        return false;
    }

    @Override
    public boolean removeUserUnableSpeak(String roomUid, String userId) {
        return false;
    }

}
